Crate logged_fu_skater

Traits

Obfuscateable
Trait to implement obfuscate functionality on relevant data types.

Functions

obf
Obfuscates the input string into a human readable hash.
obfp
Obfuscates the input string into a human readable hash with 0-8 padding_bytes at the end.